@@ -11,6 +11,7 @@ schemes extracted to the data storage path
 
 """
 
+import json
 import mimetypes
 import os
 from typing import TYPE_CHECKING
@@ -18,16 +19,18 @@ from typing import TYPE_CHECKING
 import datauri
 
 from darc._compat import datetime
-from darc.const import PATH_MISC
+from darc.const import PATH_MISC, get_lock
 
 if TYPE_CHECKING:
-    from darc.link import Link
+    import darc.link as darc_link  # Link
 
+LOCK = get_lock()
 PATH = os.path.join(PATH_MISC, 'data')
+PATH_MAP = os.path.join(PATH, 'data.txt')
 os.makedirs(PATH, exist_ok=True)
 
 
-def save_data(link: 'Link') -> None:
+def save_data(link: 'darc_link.Link') -> None:
     """Save data URI.
 
     The function will save data URIs to the data storage
@@ -44,3 +47,10 @@ def save_data(link: 'Link') -> None:
     path = os.path.join(PATH, f'{link.name}_{ts}{ext}')
     with open(path, 'wb') as file:
         file.write(data.data)
+
+    with LOCK:  # type: ignore[union-attr]
+        with open(PATH_MAP, 'a') as data_file:
+            print(json.dumps({
+                'src': backref.url if (backref := link.url_backref) is not None else None,  # pylint: disable=used-before-assignment
+                'url': path,
+            }), file=data_file)
