@@ -20,7 +20,7 @@ import traceback
 import warnings
 from typing import TYPE_CHECKING, cast
 
-import stem.util.term
+import stem.util.term as stem_term
 
 from darc.const import DARC_USER, DEBUG, VERBOSE
 from darc.error import FreenetBootstrapFailed, UnsupportedPlatform, render_error
@@ -64,15 +64,12 @@ else:
 _FREENET_ARGS.extend(FREENET_ARGS)
 
 if DEBUG:
-    print(stem.util.term.format('-*- FREENET PROXY -*-',
-                                stem.util.term.Color.MAGENTA))  # pylint: disable=no-member
+    print(stem_term.format('-*- FREENET PROXY -*-', stem_term.Color.MAGENTA))  # pylint: disable=no-member
     if _unsupported:
-        print(stem.util.term.format(f'unsupported system: {platform.system()}',
-                                    stem.util.term.Color.RED))  # pylint: disable=no-member
+        print(stem_term.format(f'unsupported system: {platform.system()}', stem_term.Color.RED))  # pylint: disable=no-member
     else:
-        print(render_error(pprint.pformat(_FREENET_ARGS), stem.util.term.Color.MAGENTA))  # pylint: disable=no-member
-    print(stem.util.term.format('-' * shutil.get_terminal_size().columns,
-                                stem.util.term.Color.MAGENTA))  # pylint: disable=no-member
+        print(render_error(pprint.pformat(_FREENET_ARGS), stem_term.Color.MAGENTA))  # pylint: disable=no-member
+    print(stem_term.format('-' * shutil.get_terminal_size().columns, stem_term.Color.MAGENTA))  # pylint: disable=no-member
 
 
 def _freenet_bootstrap() -> None:
@@ -103,9 +100,9 @@ def _freenet_bootstrap() -> None:
         stdout, stderr = error.stdout, error.stderr
     if VERBOSE:
         if stdout is not None:
-            print(render_error(stdout, stem.util.term.Color.BLUE))  # pylint: disable=no-member
+            print(render_error(stdout, stem_term.Color.BLUE))  # pylint: disable=no-member
     if stderr is not None:
-        print(render_error(stderr, stem.util.term.Color.RED))  # pylint: disable=no-member
+        print(render_error(stderr, stem_term.Color.RED))  # pylint: disable=no-member
 
     returncode = _FREENET_PROC.returncode
     if returncode != 0:
@@ -145,8 +142,8 @@ def freenet_bootstrap() -> None:
     if _FREENET_BS_FLAG:
         return
 
-    print(stem.util.term.format('-*- Freenet Bootstrap -*-',
-                                stem.util.term.Color.MAGENTA))  # pylint: disable=no-member
+    print(stem_term.format('-*- Freenet Bootstrap -*-',
+                                stem_term.Color.MAGENTA))  # pylint: disable=no-member
     for _ in range(FREENET_RETRY+1):
         try:
             _freenet_bootstrap()
@@ -154,9 +151,9 @@ def freenet_bootstrap() -> None:
         except Exception as error:
             if DEBUG:
                 message = '[Error bootstraping Freenet proxy]' + os.linesep + traceback.format_exc()
-                print(render_error(message, stem.util.term.Color.RED), end='', file=sys.stderr)  # pylint: disable=no-member
+                print(render_error(message, stem_term.Color.RED), end='', file=sys.stderr)  # pylint: disable=no-member
 
             warning = warnings.formatwarning(str(error), FreenetBootstrapFailed, __file__, 147, 'freenet_bootstrap()')
-            print(render_error(warning, stem.util.term.Color.YELLOW), end='', file=sys.stderr)  # pylint: disable=no-member
-    print(stem.util.term.format('-' * shutil.get_terminal_size().columns,
-                                stem.util.term.Color.MAGENTA))  # pylint: disable=no-member
+            print(render_error(warning, stem_term.Color.YELLOW), end='', file=sys.stderr)  # pylint: disable=no-member
+    print(stem_term.format('-' * shutil.get_terminal_size().columns,
+                                stem_term.Color.MAGENTA))  # pylint: disable=no-member
